( cd usr/bin ; rm -rf geqn )
( cd usr/bin ; ln -sf eqn geqn )
( cd usr/bin ; rm -rf gindxbib )
( cd usr/bin ; ln -sf indxbib gindxbib )
( cd usr/bin ; rm -rf gpic )
( cd usr/bin ; ln -sf pic gpic )
( cd usr/bin ; rm -rf grefer )
( cd usr/bin ; ln -sf refer grefer )
( cd usr/bin ; rm -rf gsoelim )
( cd usr/bin ; ln -sf soelim gsoelim )
( cd usr/bin ; rm -rf zsoelim )
( cd usr/bin ; ln -sf soelim zsoelim )
( cd usr/bin ; rm -rf gtbl )
( cd usr/bin ; ln -sf tbl gtbl )
( cd usr/bin ; rm -rf gtroff )
( cd usr/bin ; ln -sf troff gtroff )
( cd usr/bin ; rm -rf glookbib )
( cd usr/bin ; ln -sf lookbib glookbib )
( cd usr/bin ; rm -rf gnroff )
( cd usr/bin ; ln -sf nroff gnroff )
( cd usr/bin ; rm -rf gneqn )
( cd usr/bin ; ln -sf neqn gneqn )
